DistinguishedProxiable

Trait DistinguishedProxiable 

pub trait DistinguishedProxiable<Tag = ()>: Proxiable<Tag> {
    // Required method
    fn decode_proxy_distinguished(
        &mut self,
        proxy: Self::Proxy,
    ) -> Result<Canonicity, DecodeErrorKind>;
}
Extension trait for distinguished types that can decode by proxy.

Required Methods

fn decode_proxy_distinguished( &mut self, proxy: Self::Proxy, ) -> Result<Canonicity, DecodeErrorKind>

Try to store the value represented in the proxy’s type in this value, returning an error if the value is not valid (ideally the error should be OutOfDomainValue, InvalidValue, or Other). On success, return whether the value was a canonical representation (the same proxy value that would have been created for this value, Canonical) or not (NotCanonical).

Implementors