#[non_exhaustive]pub enum DecodeErrorKind {
Show 13 variants
Truncated,
InvalidVarint,
TagOverflowed,
WrongWireType,
OutOfDomainValue,
InvalidValue,
ConflictingFields,
UnexpectedlyRepeated,
NotCanonical,
UnknownField,
RecursionLimitReached,
Oversize,
Other,
}Expand description
Bilrost message decoding error types.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Truncated
Decoded data was truncated.
InvalidVarint
Invalid varint. (The only invalid varints are ones that would encode values > u64::MAX.)
TagOverflowed
A field key encoded a tag greater than u32::MAX.
WrongWireType
A field’s wire type was encountered that cannot encode a valid value.
OutOfDomainValue
Value was out of domain for its type.
InvalidValue
Value was invalid, such as non-UTF-8 data in a String field or an unsupported number of
items in a container.
ConflictingFields
Conflicting mutually exclusive fields.
UnexpectedlyRepeated
A field or part of a value occurred multiple times when it should not.
NotCanonical
A value was not encoded canonically. (distinguished decoding error)
UnknownField
Unknown fields were encountered. (distinguished decoding error)
RecursionLimitReached
Recursion limit was reached when parsing.
Oversize
Size of a length-delimited region exceeds what is supported on this platform.
Other
Something else.