pub struct PlainBytes;Expand description
Encoder that decodes bytes data directly into Vec<u8>, rather than requiring it to be wrapped
in Blob.
PlainBytes implements encoding for blob values directly into Vec<u8>, and provides the base
implementation for that functionality. Vec<u8> cannot generically dispatch to General’s
encoding, since General already generically implements encoding for other kinds of Vec, but
this encoder can be used instead if it’s desirable to have a value whose type is exactly
Vec<u8>.