pub struct Proxied<E, Tag = ()>(/* private fields */);Expand description
Proxied is a special encoder which translates the encoded type into its “proxy” type first,
simplifying the encoding logic. It provides value-encoding implementations for types that
implement the proxied conversions defined in Proxiable and DistinguishedProxiable, which can
then be delegated (such as with delegate_value_encoding!) to another encoding to be used as
field types in messages.
Proxied itself cannot be used to encode message fields because its
trait support means that it cannot ever implement Encoder, Decoder etc. for its supported,
un-wrapped types; only when they are nested in Option<T>, or appear in a oneof, or in some
other container.